@@ -49,6 +49,11 @@ sub gte {
     return $self;
 }
 
+sub min {
+    my ($self, $min, $opts) = @_;
+    return $self->gte($min, $opts);
+}
+
 sub lt {
     my ($self, $max, $opts) = @_;
     $opts = $opts || {};
@@ -73,6 +78,11 @@ sub lte {
     return $self;
 }
 
+sub max {
+    my ($self, $max, $opts) = @_;
+    return $self->lte($max, $opts);
+}
+
 # value must be an integer
 sub int {
     my ($self, $opts) = @_;
